@@ -195,6 +195,7 @@ Px={
   lv5:                       '.',
   lv6:                       '.',
 }
+Px[:lng_lst_rgx]=Px[:lng_lst].join('|')
 Ep={
   d_oebps:                   'OEBPS',
   f_ncx:                     'toc.ncx',
@@ -223,16 +224,21 @@ Db={
   col_info_note:             2500,
 }
 Gt={
-  grotto:                    'sisu:',
+  grotto:                    'sisu_src',
+  git:                       'sisu:',
   src:                       'src',
+  pods:                      'pods',
+  sisupod:                   'sisupod',
   pod:                       'pod',
+  files:                     'files',
+  doc:                       'doc',
   po:                        'po4a/po',
   pot:                       'po4a/pot',
-  image:                     'mm/image',
-  audio:                     'mm/audio',
-  video:                     'mm/video',
-  conf:                      'conf',
-  skin:                      'conf/skin',                                      #Gt[:skin: 'conf/skin/doc'
+  image:                     'image',
+  audio:                     'audio',
+  video:                     'video',
+  conf:                      'doc/_sisu',
+  skin:                      'doc/_sisu/skin',                                  #Gt[:skin: 'conf/skin/doc'
 }
 DISABLE={
   epub: {
