@@ -265,7 +265,7 @@ module SiSU_DAL
         tell=(@opt.cmd=~/[vVM]/) \
         ? SiSU_Screen::Ansi.new(@opt.cmd,'Document Abstraction')
         : SiSU_Screen::Ansi.new(@opt.cmd,'Document Abstraction',"[#{@opt.f_pth[:lng_is]}] #{@opt.fno}")
-        tell.green_title_hi
+        tell.grey_title_hi
       end
       fn=(@fnx && @fnx =~/\.ss[tmi]$/) \
       ? @fnx
