@@ -7,7 +7,8 @@
 
  * Author: Ralph Amissah
 
- * Copyright: (C) 1997 - 2012, Ralph Amissah, All Rights Reserved.
+ * Copyright: (C) 1997, 1998, 1999, 2000, 2001, 2002, 2003, 2004, 2005, 2006,
+   2007, 2008, 2009, 2010, 2011, 2012 Ralph Amissah, All Rights Reserved.
 
  * License: GPL 3 or later:
 
@@ -33,9 +34,7 @@
    <http://www.fsf.org/licensing/licenses/gpl.html>
    <http://www.gnu.org/licenses/gpl.html>
 
-   <http://www.jus.uio.no/sisu/gpl.fsf/toc.html>
-   <http://www.jus.uio.no/sisu/gpl.fsf/doc.html>
-   <http://www.jus.uio.no/sisu/gpl.fsf/plain.txt>
+   <http://www.sisudoc.org/sisu/en/manifest/gpl.fsf.html>
 
  * SiSU uses:
    * Standard SiSU markup syntax,
@@ -47,7 +46,7 @@
    <http://www.sisudoc.org>
 
  * Download:
-   <http://www.jus.uio.no/sisu/SiSU/download.html>
+   <http://www.sisudoc.org/sisu/en/SiSU/download.html>
 
  * Ralph Amissah
    <ralph@amissah.com>
@@ -65,10 +64,10 @@ module SiSU_Embedded
     def initialize(opt)
       @opt=opt
       @md=SiSU_Param::Parameters.new(@opt).get
-      @env=SiSU_Env::Info_env.new(@md.fns)
-      @rhost=SiSU_Env::Info_remote.new(@opt).remote_host_base
+      @env=SiSU_Env::InfoEnv.new(@md.fns)
+      @rhost=SiSU_Env::InfoRemote.new(@opt).remote_host_base
       @base_src_dir=@opt.f_pth[:pth].sub(/\/#{@opt.f_pth[:lng]}$/,'')
-      @f=SiSU_Env::SiSU_file.new(@md)
+      @f=SiSU_Env::FileOp.new(@md)
     end
     def read
       songsheet
@@ -78,7 +77,10 @@ module SiSU_Embedded
       audio
       multimedia
       begin
-      rescue; SiSU_Errors::Info_error.new($!,$@,@opt.cmd,@opt.fns).error
+      rescue
+        SiSU_Errors::InfoError.new($!,$@,@opt.cmd,@opt.fns).error do
+          __LINE__.to_s + ':' + __FILE__
+        end
       ensure
       end
     end
@@ -95,9 +97,9 @@ module SiSU_Embedded
           FileUtils::mkdir_p(img_dir) unless FileTest.directory?(img_dir)
           src_ec=@f.place_file.images.rel + '/' + @md.ec[:image].join(" #{@f.output_path.images.rel}/")
           unless @opt.fns =~/\.-sst$/
-            SiSU_Env::System_call.new(src_ec,ldest,'q').rsync('--relative',@opt.base_path)
+            SiSU_Env::SystemCall.new(src_ec,ldest,'q').rsync('--relative',@opt.base_path)
             #if @md.opt.cmd.inspect =~/R/ #rsync to remote image directory
-            #  SiSU_Env::System_call.new(src_ec,remote_rel,'q').rsync('--relative')
+            #  SiSU_Env::SystemCall.new(src_ec,remote_rel,'q').rsync('--relative')
             #end
           end
         end
@@ -113,9 +115,9 @@ module SiSU_Embedded
         and FileTest.directory?(src)
           FileUtils::mkdir_p(ldest) unless FileTest.directory?(ldest)
           src_ec="#{src}/" + @md.ec[:audio].join(" #{src}/")
-          SiSU_Env::System_call.new(src_ec,"#{ldest}/.",'q').rsync
+          SiSU_Env::SystemCall.new(src_ec,"#{ldest}/.",'q').rsync
           if @md.opt.cmd.inspect =~/R/ #rsync to remote audio directory
-            SiSU_Env::System_call.new(src_ec,"#{rdest}/.",'q').rsync
+            SiSU_Env::SystemCall.new(src_ec,"#{rdest}/.",'q').rsync
           end
         end
       end
@@ -130,9 +132,9 @@ module SiSU_Embedded
         and FileTest.directory?(src)
           FileUtils::mkdir_p(ldest) unless FileTest.directory?(ldest)
           src_ec="#{src}/" + @md.ec[:multimedia].join(" #{src}/")
-          SiSU_Env::System_call.new(src_ec,"#{ldest}/.",'q').rsync
+          SiSU_Env::SystemCall.new(src_ec,"#{ldest}/.",'q').rsync
           if @md.opt.cmd.inspect =~/R/ #rsync to remote video directory
-            SiSU_Env::System_call.new(src_ec,"#{rdest}/.",'q').rsync
+            SiSU_Env::SystemCall.new(src_ec,"#{rdest}/.",'q').rsync
           end
         end
       end
