@@ -9,7 +9,8 @@
 
  * Author: Ralph Amissah
 
- * Copyright: (C) 1997 - 2012, Ralph Amissah, All Rights Reserved.
+ * Copyright: (C) 1997, 1998, 1999, 2000, 2001, 2002, 2003, 2004, 2005, 2006,
+   2007, 2008, 2009, 2010, 2011, 2012 Ralph Amissah, All Rights Reserved.
 
  * License: GPL 3 or later:
 
@@ -33,11 +34,9 @@
    If you have Internet connection, the latest version of the GPL should be
    available at these locations:
    <http://www.fsf.org/licensing/licenses/gpl.html>
-   <http://www.gnu.org/copyleft/gpl.html>
+   <http://www.gnu.org/licenses/gpl.html>
 
-   <http://www.jus.uio.no/sisu/gpl.fsf/toc.html>
-   <http://www.jus.uio.no/sisu/gpl.fsf/doc.html>
-   <http://www.jus.uio.no/sisu/gpl.fsf/plain.txt>
+   <http://www.sisudoc.org/sisu/en/manifest/gpl.fsf.html>
 
  * SiSU uses:
    * Standard SiSU markup syntax,
@@ -49,7 +48,7 @@
    <http://www.sisudoc.org>
 
  * Download:
-   <http://www.jus.uio.no/sisu/SiSU/download.html>
+   <http://www.sisudoc.org/sisu/en/SiSU/download.html>
 
  * Ralph Amissah
    <ralph@amissah.com>
@@ -71,9 +70,14 @@ module SiSU_Harvest
       @env=SiSU_Env::InfoEnv.new
     end
     def read
-      harvest_pth="#{@env.path.webserv}/#{@opt.base_stub}"
-      FileUtils::mkdir_p(harvest_pth) unless FileTest.directory?(harvest_pth)
-      cases(@opt,@env)
+      begin
+        harvest_pth="#{@env.path.webserv}/#{@opt.base_stub}"
+        FileUtils::mkdir_p(harvest_pth) unless FileTest.directory?(harvest_pth)
+        cases(@opt,@env)
+      rescue
+      ensure
+        SiSU_Env::CreateSite.new(@opt.cmd).cp_css
+      end
     end
     def help
       puts <<WOK
