@@ -7,7 +7,8 @@
 
  * Author: Ralph Amissah
 
- * Copyright: (C) 1997 - 2012, Ralph Amissah, All Rights Reserved.
+ * Copyright: (C) 1997, 1998, 1999, 2000, 2001, 2002, 2003, 2004, 2005, 2006,
+   2007, 2008, 2009, 2010, 2011, 2012 Ralph Amissah, All Rights Reserved.
 
  * License: GPL 3 or later:
 
@@ -33,9 +34,7 @@
    <http://www.fsf.org/licensing/licenses/gpl.html>
    <http://www.gnu.org/licenses/gpl.html>
 
-   <http://www.jus.uio.no/sisu/gpl.fsf/toc.html>
-   <http://www.jus.uio.no/sisu/gpl.fsf/doc.html>
-   <http://www.jus.uio.no/sisu/gpl.fsf/plain.txt>
+   <http://www.sisudoc.org/sisu/en/manifest/gpl.fsf.html>
 
  * SiSU uses:
    * Standard SiSU markup syntax,
@@ -47,7 +46,7 @@
    <http://www.sisudoc.org>
 
  * Download:
-   <http://www.jus.uio.no/sisu/SiSU/download.html>
+   <http://www.sisudoc.org/sisu/en/SiSU/download.html>
 
  * Ralph Amissah
    <ralph@amissah.com>
@@ -270,50 +269,6 @@ module SiSU_HTML_Format
       else ''
       end
     end
-    def txt #retired 2.7.9
-      txt=if @cf_defaults.cf_0 =~/[at]/
-        %{
-<td valign=bottom bgcolor=#{@vz.color_band2}>
-  <a href="#{Xx[:html_relative1]}txt/#{@file.base_filename.txt}" target="_top" #{@vz.js_plaintext}>
-    #{@vz.nav_txt_plaintext}
-  </a>
-</td>}
-      else ''
-      end
-    end
-    def epub #retired 2.7.9
-      epub=if @cf_defaults.cf_0 =~/e/
-        %{
-<td align="center" bgcolor=#{@vz.color_band2}>
-  <a href="#{Xx[:html_relative1]}epub/#{@file.base_filename.epub}" target="_top" #{@vz.js_epub}>
-    #{@vz.nav_txt_epub}
-  </a>
-</td>}
-      else ''
-      end
-    end
-    def odf #retired 2.7.9
-      odf=if @cf_defaults.cf_0 =~/o/
-        %{
-<td align="center" bgcolor=#{@vz.color_band2}>
-  <a href="#{Xx[:html_relative1]}odt/#{@file.base_filename.odt}" target="_top" #{@vz.js_odf}>
-    #{@vz.nav_txt_odf}
-  </a>
-</td>}
-      else ''
-      end
-    end
-    def concordance(text) #retired 2.7.9
-      if @md.concord_make \
-      and @md.wc_words < 300000 #max word count for display of concordance here as would now be a large file
-  %{<td align="center" bgcolor=#{@vz.color_band2}>
-    <a href="#{@md.file.base_filename.html_concordance}" target="_top" #{@vz.js_concordance}>
-      #{text}
-    </a>
-  </td>}
-      else ''
-      end
-    end
   end
   class XML
   end
