@@ -350,11 +350,16 @@ module SiSU_HTML_Seg
     def head(dob)
       clean=/<!.*?!>|<:.*?>/
       format_head_seg=SiSU_HTML_Format::HeadSeg.new(@md)
-      if @@tracker < @@seg_total-1
-        if @@tracker==0; @@segtocband=format_head_seg.toc_next2 #if format_head_seg.toc_next2
-        else             @@segtocband=format_head_seg.toc_pre_next2 #if format_head_seg.toc_pre_next2
+      if @make.build.html_navigation?
+        if @@tracker < @@seg_total-1
+          @@segtocband=if @@tracker==0
+            format_head_seg.toc_next2 #if format_head_seg.toc_next2
+          else
+            format_head_seg.toc_pre_next2 #if format_head_seg.toc_pre_next2
+          end
+        else @@segtocband=format_head_seg.toc_pre2 #if format_head_seg.toc_pre2
         end
-      else @@segtocband=format_head_seg.toc_pre2 #if format_head_seg.toc_pre2
+      else @@segtocband=''
       end
       @p_num ||= ''
       if @@is1==1
