@@ -475,12 +475,10 @@ WOK
         end
       end
       def source_tests
-        if @md.fns =~/\.ssm\.sst$/                                                  #% decide whether to extract and include requested/required documents
-          req=@md.fns
+        if @md.fno =~/\.ssm$/                                                  #% decide whether to extract and include requested/required documents
           if FileTest.file?(@f.place_file.src.dir)==true
             pth=@f.output_path.src.dir
-            rel=@f.output_path.src.rel
-            #rel=@f.output_path.src.rel_sm
+            rel=@f.output_path.src.rel_sm
             url=@f.output_path.src.url
             id,file='Markup Composite File (SiSU source)',@f.base_filename.src
             summarize_sources(id,file,pth,rel,url)
