@@ -7,7 +7,8 @@
 
  * Author: Ralph Amissah
 
- * Copyright: (C) 1997 - 2012, Ralph Amissah, All Rights Reserved.
+ * Copyright: (C) 1997, 1998, 1999, 2000, 2001, 2002, 2003, 2004, 2005, 2006,
+   2007, 2008, 2009, 2010, 2011, 2012 Ralph Amissah, All Rights Reserved.
 
  * License: GPL 3 or later:
 
@@ -33,9 +34,7 @@
    <http://www.fsf.org/licensing/licenses/gpl.html>
    <http://www.gnu.org/licenses/gpl.html>
 
-   <http://www.jus.uio.no/sisu/gpl.fsf/toc.html>
-   <http://www.jus.uio.no/sisu/gpl.fsf/doc.html>
-   <http://www.jus.uio.no/sisu/gpl.fsf/plain.txt>
+   <http://www.sisudoc.org/sisu/en/manifest/gpl.fsf.html>
 
  * SiSU uses:
    * Standard SiSU markup syntax,
@@ -47,7 +46,7 @@
    <http://www.sisudoc.org>
 
  * Download:
-   <http://www.jus.uio.no/sisu/SiSU/download.html>
+   <http://www.sisudoc.org/sisu/en/SiSU/download.html>
 
  * Ralph Amissah
    <ralph@amissah.com>
@@ -56,11 +55,11 @@
  ** Description: manpage formatting template
 
 =end
-module SiSU_Manpage_format
+module SiSU_ManpageFormat
   require_relative 'param'                              # param.rb
     include SiSU_Param
   include SiSU_Viz
-  class Paragraph_number
+  class ParagraphNumber
     def initialize(paranum)
       @paranum=/(\d+)/m.match(paranum)[1]
     end
@@ -74,7 +73,7 @@ module SiSU_Manpage_format
       @paranum.gsub(/(\d+)/,'<a href="#\1">')
     end
   end
-  class Format_text_object
+  class FormatTextObject
     def initialize(md,dob)
       @md,@dob=md,dob
 if @dob.class==Hash
@@ -84,7 +83,7 @@ elsif @dob.class==String
 end
       rgx=/#{Mx[:en_a_o]}[\d*+]+\s+(.+?)#{Mx[:en_a_c]}/
       @dob.obj.gsub!(rgx,'\1') if @dob.obj =~rgx
-      @vz=SiSU_Env::Get_init.instance.skin
+      @vz=SiSU_Env::GetInit.instance.skin
     end
     def scr_endnote_body
       "<endnote>#{@dob.obj}</endnote> "
