@@ -60,6 +60,7 @@ module SiSU_Po4a
   require_relative 'dal'                                # dal.rb
   require_relative 'sysenv'                             # sysenv.rb
     include SiSU_Env
+  require_relative 'composite'                          # composite.rb
   require_relative 'shared_metadata'                    # shared_metadata.rb
   require_relative 'po4a_set'                           # po4a_set.rb
   include SiSU_Param
@@ -72,8 +73,7 @@ module SiSU_Po4a
       #unless @opt.fns =~/(.+?\.(?:-|ssm\.)?sst)$/
       #  puts "#{@opt.fns} not a processed file type"
       #end
-      r=Px[:lng_lst].join('|')
-      r=r.gsub(/\|en\|/,'|')
+      r=Px[:lng_lst_rgx].gsub(/\|en\|/,'|')
       @lang_regx=%r{(?:#{r})}
       if opt.fns =~/\S+?~#{@lang_regx}\.ss[mti]/ \
       and opt.f_pth[:lng]!=@opt.lng_base
