@@ -130,7 +130,8 @@ module SiSU_Images
           rgx_rb_image=/["']\S*?([a-zA-Z0-9_-]+?\.(?:png|jpg|gif))["']/
           skin_source=SiSU_Env::InfoSkin.new(@md).apply
           docskin=nil
-          if skin_source[:type] == :dir
+          if skin_source \
+          and skin_source[:type] == :dir
             docskin_with_path="#{docskin_place}/skin_#{@env.stub_pwd}.rb"
             docskin=[docskin_with_path.gsub(/.+?\/(skin_\S+?)\.rb/,'\1')]
             #docskin='skin_sisupod'
