@@ -7,7 +7,8 @@
 
  * Author: Ralph Amissah
 
- * Copyright: (C) 1997 - 2012, Ralph Amissah, All Rights Reserved.
+ * Copyright: (C) 1997, 1998, 1999, 2000, 2001, 2002, 2003, 2004, 2005, 2006,
+   2007, 2008, 2009, 2010, 2011, 2012 Ralph Amissah, All Rights Reserved.
 
  * License: GPL 3 or later:
 
@@ -33,9 +34,7 @@
    <http://www.fsf.org/licensing/licenses/gpl.html>
    <http://www.gnu.org/licenses/gpl.html>
 
-   <http://www.jus.uio.no/sisu/gpl.fsf/toc.html>
-   <http://www.jus.uio.no/sisu/gpl.fsf/doc.html>
-   <http://www.jus.uio.no/sisu/gpl.fsf/plain.txt>
+   <http://www.sisudoc.org/sisu/en/manifest/gpl.fsf.html>
 
  * SiSU uses:
    * Standard SiSU markup syntax,
@@ -47,7 +46,7 @@
    <http://www.sisudoc.org>
 
  * Download:
-   <http://www.jus.uio.no/sisu/SiSU/download.html>
+   <http://www.sisudoc.org/sisu/en/SiSU/download.html>
 
  * Ralph Amissah
    <ralph@amissah.com>
@@ -56,7 +55,7 @@
  ** Description: modules shared by flatfile output generators
 
 =end
-module SiSU_text_utils
+module SiSU_TextUtils
   class Wrap
     def initialize(para='',n_char_max=76,n_indent=0,n_hang=nil)
       @para,@n_char_max,@n_indent=para,n_char_max,n_indent
@@ -70,8 +69,8 @@ module SiSU_text_utils
       line=0
       out=[]
       out[line]=''
-      @para.gsub!(/<br>/,' <br> ')
-      @para.gsub!(/#{Mx[:br_nl]}/,"\n\n")
+      @para=@para.gsub(/<br>/,' <br> ').
+        gsub(/#{Mx[:br_nl]}/,"\n\n")
       words=@para.scan(/\n\n|<br>|\S+/m)
       while words != ''
         word=words.shift
@@ -118,13 +117,13 @@ module SiSU_text_utils
       if @para.class==Array
         @arr=[]
         @para.each do |line|
-          @arr << SiSU_text_utils::Wrap.new(line,@n_char_max,@n_indent,@n_hang).line_wrap
+          @arr << SiSU_TextUtils::Wrap.new(line,@n_char_max,@n_indent,@n_hang).line_wrap
         end
       end
       @arr
     end
   end
-  class Header_scan
+  class HeaderScan
     def initialize(md,para)
       @md,@p=md,para
     end
