@@ -7,7 +7,8 @@
 
  * Author: Ralph Amissah
 
- * Copyright: (C) 1997 - 2012, Ralph Amissah, All Rights Reserved.
+ * Copyright: (C) 1997, 1998, 1999, 2000, 2001, 2002, 2003, 2004, 2005, 2006,
+   2007, 2008, 2009, 2010, 2011, 2012 Ralph Amissah, All Rights Reserved.
 
  * License: GPL 3 or later:
 
@@ -33,9 +34,7 @@
    <http://www.fsf.org/licensing/licenses/gpl.html>
    <http://www.gnu.org/licenses/gpl.html>
 
-   <http://www.jus.uio.no/sisu/gpl.fsf/toc.html>
-   <http://www.jus.uio.no/sisu/gpl.fsf/doc.html>
-   <http://www.jus.uio.no/sisu/gpl.fsf/plain.txt>
+   <http://www.sisudoc.org/sisu/en/manifest/gpl.fsf.html>
 
  * SiSU uses:
    * Standard SiSU markup syntax,
@@ -47,7 +46,7 @@
    <http://www.sisudoc.org>
 
  * Download:
-   <http://www.jus.uio.no/sisu/SiSU/download.html>
+   <http://www.sisudoc.org/sisu/en/SiSU/download.html>
 
  * Ralph Amissah
    <ralph@amissah.com>
@@ -70,7 +69,7 @@ def talent(termsheet,flag)
   no_ocn='0' if flag =~/0/ #flag to request switch off of text object numbering
   @@info=nil
   @@info=termsheet.gsub(/(.+?)\.termsheet\.rb/,'../facility_data/\1.html')
-  @env=SiSU_Env::Info_env.new
+  @env=SiSU_Env::InfoEnv.new
   @dir_fd="#{@env.path.output}/facility_data"
   FileUtils::mkdir_p(@dir_fd) unless FileTest.directory?(@dir_fd)==true
   html_output=[]
@@ -130,7 +129,7 @@ if @proc =~  /^-?[wft]/
     talent(termsheet,@proc)
   end
 end
-@env=SiSU_Env::Info_env.new
+@env=SiSU_Env::InfoEnv.new
 @dir_fd="#{@env.path.output}/facility_data"
 @url="#{@env.url.webserv}/facility_data"
 @@report << %{\n#{@@cX.grey}See#{@@cX.off}: #{@@cX.blue}#{@dir_fd}/all.txt\t#{@dir_fd}/toc.html\t#{@dir_fd}/#{@@cX.off}\n\n#{@@cX.grey}See#{@@cX.off}: #{@@cX.blue}#{@url}/all.txt\t#{@url}/toc.html\t#{@url}/#{@@cX.off}\n\n}
