@@ -7,7 +7,8 @@
 
  * Author: Ralph Amissah
 
- * Copyright: (C) 1997 - 2012, Ralph Amissah, All Rights Reserved.
+ * Copyright: (C) 1997, 1998, 1999, 2000, 2001, 2002, 2003, 2004, 2005, 2006,
+   2007, 2008, 2009, 2010, 2011, 2012 Ralph Amissah, All Rights Reserved.
 
  * License: GPL 3 or later:
 
@@ -33,9 +34,7 @@
    <http://www.fsf.org/licensing/licenses/gpl.html>
    <http://www.gnu.org/licenses/gpl.html>
 
-   <http://www.jus.uio.no/sisu/gpl.fsf/toc.html>
-   <http://www.jus.uio.no/sisu/gpl.fsf/doc.html>
-   <http://www.jus.uio.no/sisu/gpl.fsf/plain.txt>
+   <http://www.sisudoc.org/sisu/en/manifest/gpl.fsf.html>
 
  * SiSU uses:
    * Standard SiSU markup syntax,
@@ -47,7 +46,7 @@
    <http://www.sisudoc.org>
 
  * Download:
-   <http://www.jus.uio.no/sisu/SiSU/download.html>
+   <http://www.sisudoc.org/sisu/en/SiSU/download.html>
 
  * Ralph Amissah
    <ralph@amissah.com>
@@ -72,7 +71,10 @@ module SiSU_UpdateControlFlag
         base_path="#{out}/#{@md.fnb}"
         SiSU_Screen::Ansi.new(@md.opt.cmd,'Checking previous output',base_path).green_hi_blue unless @md.opt.cmd =~/q/
         SetCF.new(@md).set_flags
-      rescue; SiSU_Errors::InfoError.new($!,$@,@md.opt.cmd,@md.fns).error
+      rescue
+        SiSU_Errors::InfoError.new($!,$@,@md.opt.cmd,@md.fns).error do
+          __LINE__.to_s + ':' + __FILE__
+        end
       ensure
       end
     end
