@@ -90,10 +90,6 @@ module SiSU_Urls
       @fn=SiSU_Env::EnvCall.new(@opt.fns).lang(fn_set_lang[:c])
       @m_regular=/(.+?)\.(?:(?:-|ssm\.)?sst|ssm)$/
       @prog=@env.program
-      source=if @opt.fns =~/\.sst$/; @opt.fns
-      elsif @opt.fns =~/\.ssm\.sst/; "#{@fnb}.ssm.sst"
-      else 'not recognised file'
-      end
       @u ||= {
         'b --xhtml (XHTML)'=>@fn[:xhtml],
         'D[iu] --psql (DBI import/update postgresql)'=>'dbi psql',
@@ -111,7 +107,7 @@ module SiSU_Urls
         'p --pdf (PDF landscape)'=>@fn[:pdf_l],
         'p --pdf (PDF portrait)'=>@fn[:pdf_p],
         'E --profile (Ruby profiler)'=>'profile',
-        's --source (sisu markup)'=>source,
+        's --source (sisu markup)'=>@opt.fno,
         'S --sisupod (sisupod)'=>@fn[:sisupod],
         't --txt (Plain-text (endnotes))'=>@fn[:plain],
         'x --xml-sax (XML sax type)'=>@fn[:sax],
@@ -361,7 +357,7 @@ module SiSU_Urls
               end
               if x=~/--sisupod\b/ \
               and @opt.act[:sisupod][:set]==:on
-                (@opt.fns =~/\.ssm\.sst$/) \
+                (@opt.fno =~/\.ssm$/) \
                 ? y.gsub(/(?:\~\S{2,3})?(\.ssm.sst\.txz)$/,'.ssm.txz')
                 : y.gsub(/(?:\~\S{2,3})?(\.sst\.txz)$/,'\1')
                 show.source.pod(x,y)
