@@ -7,7 +7,8 @@
 
  * Author: Ralph Amissah
 
- * Copyright: (C) 1997 - 2012, Ralph Amissah, All Rights Reserved.
+ * Copyright: (C) 1997, 1998, 1999, 2000, 2001, 2002, 2003, 2004, 2005, 2006,
+   2007, 2008, 2009, 2010, 2011, 2012 Ralph Amissah, All Rights Reserved.
 
  * License: GPL 3 or later:
 
@@ -33,9 +34,7 @@
    <http://www.fsf.org/licensing/licenses/gpl.html>
    <http://www.gnu.org/licenses/gpl.html>
 
-   <http://www.jus.uio.no/sisu/gpl.fsf/toc.html>
-   <http://www.jus.uio.no/sisu/gpl.fsf/doc.html>
-   <http://www.jus.uio.no/sisu/gpl.fsf/plain.txt>
+   <http://www.sisudoc.org/sisu/en/manifest/gpl.fsf.html>
 
  * SiSU uses:
    * Standard SiSU markup syntax,
@@ -47,7 +46,7 @@
    <http://www.sisudoc.org>
 
  * Download:
-   <http://www.jus.uio.no/sisu/SiSU/download.html>
+   <http://www.sisudoc.org/sisu/en/SiSU/download.html>
 
  * Ralph Amissah
    <ralph@amissah.com>
@@ -56,7 +55,7 @@
  ** Description: summary of generated outputs and metadata
 
 =end
-module SiSU_XML_metadata
+module SiSU_XML_Metadata
   require_relative 'sysenv'                             # sysenv.rb
     include SiSU_Env
   require_relative 'param'                              # param.rb
@@ -184,7 +183,7 @@ WOK
     end
     def meta_content_clean(content='')
       unless content.nil?
-        content.tr!('"',"'")
+        content=content.tr('"',"'")
       end
       content
     end
@@ -192,8 +191,8 @@ WOK
       '</oai_dc:dc>'
     end
     def output
-      SiSU_Env::SiSU_file.new(@md).mkdir
-      oai_pmh=SiSU_Env::SiSU_file.new(@md,@md.fn[:oai_pmh]).mkfile #implement in param
+      SiSU_Env::FileOp.new(@md).mkdir
+      oai_pmh=SiSU_Env::FileOp.new(@md,@md.fn[:oai_pmh]).mkfile #implement in param
       oai_pmh << pre
       body.each do |x|
         oai_pmh << x
