@@ -3,11 +3,12 @@
 
  * Name: SiSU
 
- * Description: extract and print an XML rendition of document structure to screen
+ * Description: a framework for document structuring, publishing and search
 
  * Author: Ralph Amissah
 
- * Copyright: (C) 1997 - 2012, Ralph Amissah, All Rights Reserved.
+ * Copyright: (C) 1997, 1998, 1999, 2000, 2001, 2002, 2003, 2004, 2005, 2006,
+   2007, 2008, 2009, 2010, 2011, 2012 Ralph Amissah, All Rights Reserved.
 
  * License: GPL 3 or later:
 
@@ -33,9 +34,7 @@
    <http://www.fsf.org/licensing/licenses/gpl.html>
    <http://www.gnu.org/licenses/gpl.html>
 
-   <http://www.jus.uio.no/sisu/gpl.fsf/toc.html>
-   <http://www.jus.uio.no/sisu/gpl.fsf/doc.html>
-   <http://www.jus.uio.no/sisu/gpl.fsf/plain.txt>
+   <http://www.sisudoc.org/sisu/en/manifest/gpl.fsf.html>
 
  * SiSU uses:
    * Standard SiSU markup syntax,
@@ -47,13 +46,13 @@
    <http://www.sisudoc.org>
 
  * Download:
-   <http://www.jus.uio.no/sisu/SiSU/download.html>
+   <http://www.sisudoc.org/sisu/en/SiSU/download.html>
 
  * Ralph Amissah
    <ralph@amissah.com>
    <ralph.amissah@gmail.com>
 
- ** Description: SiSU information Structuring Universe, processing
+ ** Description: extract and print an XML rendition of document structure to screen
 
 =end
 module SiSU_XML_Scaffold
